@@ -29,7 +29,7 @@ def illumina_qual_bin(in_file, ref_file, out_dir, config):
                                     config_utils.get_program("cram", config, "dir"))
     samtools = config_utils.get_program("samtools", config)
     if not file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             orig_header = "%s-header.sam" % os.path.splitext(out_file)[0]
             header_cmd = "{samtools} view -H -o {orig_header} {in_file}"
             cmd = ("java {jvm_opts} -jar {cram_jar} cram --input-bam-file {in_file} "
@@ -51,7 +51,7 @@ def compress(in_bam, ref_file, config):
     resources = config_utils.get_resources("cram", config)
     jvm_opts = " ".join(resources.get("jvm_opts", ["-Xms1500m", "-Xmx3g"]))
     if not utils.file_exists(out_file):
-        with file_transaction(out_file) as tx_out_file:
+        with file_transaction(config, out_file) as tx_out_file:
             cmd = ("cramtools {jvm_opts} cram "
                    "--input-bam-file {in_bam} "
                    "--capture-all-tags "
@@ -60,14 +60,14 @@ def compress(in_bam, ref_file, config):
                    "--lossy-quality-score-spec '*8' "
                    "--output-cram-file {tx_out_file}")
             subprocess.check_call(cmd.format(**locals()), shell=True)
-    index(out_file)
+    index(out_file, config)
     return out_file
 
-def index(in_cram):
+def index(in_cram, config):
     """Ensure CRAM file has a .crai index file using cram_index from scramble.
     """
     if not utils.file_exists(in_cram + ".crai"):
-        with file_transaction(in_cram + ".crai") as tx_out_file:
+        with file_transaction(config, in_cram + ".crai") as tx_out_file:
             tx_in_file = os.path.splitext(tx_out_file)[0]
             utils.symlink_plus(in_cram, tx_in_file)
             cmd = "cram_index {tx_in_file}"
