@@ -297,6 +297,7 @@ def _run_kraken(data, ratio):
     kraken_out = os.path.join(qc_dir, "kraken")
     out = out_stats = None
     db = data['config']["algorithm"]["kraken"]
+    kraken_cmd = config_utils.get_program("kraken", data["config"])
     if db == "minikraken":
         db = os.path.join(_get_data_dir(), "genomes", "kraken", "minikraken")
     else:
@@ -307,20 +308,19 @@ def _run_kraken(data, ratio):
         work_dir = os.path.dirname(kraken_out)
         utils.safe_makedir(work_dir)
         num_cores = data["config"]["algorithm"].get("num_cores", 1)
-        files = data["files"]
-        if files[0].endswith("bam"):
+        fn_file = data["files"][0]
+        if fn_file.endswith("bam"):
             logger.info("kraken: need fasta files as input")
             return {"kraken_report": "null"}
         with tx_tmpdir(data, work_dir) as tx_tmp_dir:
             with utils.chdir(tx_tmp_dir):
                 out = os.path.join(tx_tmp_dir, "kraken_out")
                 out_stats = os.path.join(tx_tmp_dir, "kraken_stats")
-                cl = (" ").join(
-                    [config_utils.get_program("kraken", data["config"]),
-                        "--db", db, "--quick",
-                        "--preload", "--min-hits", "2",
-                        "--threads", str(num_cores),
-                        "--out", out, files[0], " 2>", out_stats])
+                cat = "zcat" if fn_file.endswith(".gz") else "cat"
+                cl = ("{cat} {fn_file} | {kraken_cmd} --db {db} --quick "
+                      "--preload --min-hits 2 "
+                      "--threads {num_cores} "
+                      "--out {out} --fastq-input /dev/stdin  2> {out_stats}").format(**locals())
                 do.run(cl, "kraken: %s" % data["name"][-1])
                 if os.path.exists(kraken_out):
                     shutil.rmtree(kraken_out)
@@ -336,6 +336,7 @@ def _parse_kraken_output(out_dir, db, data):
     in_file = os.path.join(out_dir, "kraken_out")
     stat_file = os.path.join(out_dir, "kraken_stats")
     out_file = os.path.join(out_dir, "kraken_summary")
+    kraken_cmd = config_utils.get_program("kraken-report", data["config"])
     classify = unclassify = None
     with open(stat_file, 'r') as handle:
         for line in handle:
@@ -343,12 +344,29 @@ def _parse_kraken_output(out_dir, db, data):
                 classify = line[line.find("(") + 1:line.find(")")]
             if line.find(" unclassified") > -1:
                 unclassify = line[line.find("(") + 1:line.find(")")]
-    if os.path.getsize(in_file) > 0:
+    if os.path.getsize(in_file) > 0 and not os.path.exists(out_file):
         with file_transaction(data, out_file) as tx_out_file:
-            cl = (" ").join([config_utils.get_program("kraken-report", data["config"]),
-                             "--db", db, in_file, ">", tx_out_file])
+            cl = ("{kraken_cmd} --db {db} {in_file} > {tx_out_file}").format(**locals())
             do.run(cl, "kraken report: %s" % data["name"][-1])
-    return {"kraken_report": out_file, "kraken_clas": classify, "kraken_unclas": unclassify}
+    kraken = {"kraken_clas": classify, "kraken_unclas": unclassify}
+    kraken_sum = _summarize_kraken(out_file)
+    kraken.update(kraken_sum)
+    return kraken
+
+
+def _summarize_kraken(fn):
+    """get the value at species level"""
+    kraken = {}
+    list_sp, list_value = [], []
+    with open(fn) as handle:
+        for line in handle:
+            cols = line.strip().split("\t")
+            sp = cols[5].strip()
+            if len(sp.split(" ")) > 1 and not sp.startswith("cellular"):
+                list_sp.append(sp)
+                list_value.append(cols[0])
+    kraken = {"kraken_sp": list_sp, "kraken_value": list_value}
+    return kraken
 
 
 def _run_fastqc(bam_file, data, fastqc_out):
@@ -685,11 +703,12 @@ def qsignature_summary(*samples):
                             "-log {log} -dir {out_dir} "
                             "-o {file_txt_out} ")
                 do.run(base_cmd.format(**locals()), "qsignature score calculation")
-        warnings, similar = _parse_qsignature_output(out_file, out_ma_file, out_warn_file,
-                                                     samples[0][0])
+        error, warnings, similar = _parse_qsignature_output(out_file, out_ma_file,
+                                                            out_warn_file, samples[0][0])
         return [{'total samples': count,
-                 'similar samples': len(similar),
-                 'warnings samples': list(warnings),
+                 'similar samples pairs': len(similar),
+                 'warnings samples pairs': len(warnings),
+                 'error samples': list(error),
                  'out_dir': qc_out_dir}]
     else:
         return []
@@ -706,34 +725,38 @@ def _parse_qsignature_output(in_file, out_file, warning_file, data):
 
     """
     name = {}
-    warnings = set()
-    similar = set()
+    error, warnings, similar = set(), set(), set()
+    same, replicate, related = 0, 0.1, 0.18
+    mixup_check = dd.get_mixup_check(data)
+    if mixup_check == "qsignature_full":
+        same, replicate, related = 0, 0.01, 0.061
     with open(in_file, 'r') as in_handle:
         with file_transaction(data, out_file) as out_tx_file:
             with file_transaction(data, warning_file) as warn_tx_file:
                 with open(out_tx_file, 'w') as out_handle:
                     with open(warn_tx_file, 'w') as warn_handle:
-                        ET = lxml.etree.parse(in_handle)
-                        for i in list(ET.iter('file')):
+                        et = lxml.etree.parse(in_handle)
+                        for i in list(et.iter('file')):
                             name[i.attrib['id']] = os.path.basename(i.attrib['name']).replace(".qsig.vcf", "")
-                        for i in list(ET.iter('comparison')):
+                        for i in list(et.iter('comparison')):
+                            msg = None
+                            pair = "-".join([name[i.attrib['file1']], name[i.attrib['file2']]])
                             out_handle.write("%s\t%s\t%s\n" %
-                            (name[i.attrib['file1']], name[i.attrib['file2']], i.attrib['score']))
-                            if float(i.attrib['score']) < 0.1:
-                                logger.info('qsignature WARNING: risk of duplicated samples:%s' %
-                                    (' '.join([name[i.attrib['file1']], name[i.attrib['file2']]])))
-                                warn_handle.write('qsignature WARNING: risk of duplicated samples:%s\n' %
-                                    (' '.join([name[i.attrib['file1']], name[i.attrib['file2']]])))
-                                warnings.add(name[i.attrib['file1']])
-                                warnings.add(name[i.attrib['file2']])
-                            elif float(i.attrib['score']) < 0.18:
-                                logger.info('qsignature: read similar samples:%s' %
-                                    (' '.join([name[i.attrib['file1']], name[i.attrib['file2']]])))
-                                warn_handle.write('qsignature NOTE: similar samples:%s\n' %
-                                    (' '.join([name[i.attrib['file1']], name[i.attrib['file2']]])))
-                                similar.add(name[i.attrib['file1']])
-                                similar.add(name[i.attrib['file2']])
-    return warnings, similar
+                                             (name[i.attrib['file1']], name[i.attrib['file2']], i.attrib['score']))
+                            if float(i.attrib['score']) == same:
+                                msg = 'qsignature ERROR: read same samples:%s\n'
+                                error.add(pair)
+                            elif float(i.attrib['score']) < replicate:
+                                msg = 'qsignature WARNING: read similar/replicate samples:%s\n'
+                                warnings.add(pair)
+                            elif float(i.attrib['score']) < related:
+                                msg = 'qsignature NOTE: read relative samples:%s\n'
+                                similar.add(pair)
+                            if msg:
+                                logger.info(msg % pair)
+                                warn_handle.write(msg % pair)
+    return error, warnings, similar
+
 
 def _slice_chr22(in_bam, data):
     """
