@@ -132,12 +132,24 @@ def process_alignment(data):
         raise ValueError("Could not process input file: %s" % fastq1)
     return [[data]]
 
+def prep_samples(*items):
+    """Handle any global preparatory steps for samples with potentially shared data.
+
+    Avoids race conditions in postprocess alignment when performing prep tasks
+    on shared files between multiple similar samples.
+
+    Cleans input BED files to avoid issues with overlapping input segments.
+    """
+    out = []
+    for data in (x[0] for x in items):
+        data = bedutils.clean_inputs(data)
+        out.append([data])
+    return out
+
 def postprocess_alignment(data):
     """Perform post-processing steps required on full BAM files.
     Prepares list of callable genome regions allowing subsequent parallelization.
-    Cleans input BED files to avoid issues with overlapping input segments.
     """
-    data = bedutils.clean_inputs(data)
     if vmulti.bam_needs_processing(data) and data["work_bam"].endswith(".bam"):
         callable_region_bed, nblock_bed, callable_bed = \
             callable.block_regions(data["work_bam"], data["sam_ref"], data["config"])
