@@ -10,10 +10,6 @@ import os
 
 import toolz as tz
 import numpy as np
-try:
-    import pybedtools
-except ImportError:
-    pybedtools = None
 try:
     import pandas as pd
     import prettyplotlib as ppl
@@ -34,6 +30,7 @@ def _stat_str(x, n):
 def _evaluate_one(caller, svtype, size_range, ensemble, truth, exclude):
     """Compare a ensemble results for a caller against a specific caller and SV type.
     """
+    import pybedtools
     def cnv_matches(name):
         """Check for CNV matches -- XXX hardcoded for diploid comparisons.
         """
@@ -152,7 +149,7 @@ def evaluate(data, sv_calls):
         val_summary, df_csv = _evaluate_multi(callers, truth_sets, ensemble_bed, exclude_file)
         summary_plot = _plot_evaluation(df_csv)
         ensemble_i, ensemble = ensemble_callsets[0]
-        ensemble["validate"] = {"csv": "val_summary", "plot": summary_plot}
+        ensemble["validate"] = {"csv": val_summary, "plot": summary_plot}
         sv_calls[ensemble_i] = ensemble
     return sv_calls
 
