@@ -1,6 +1,6 @@
 """Create bcbio_sample.yaml files from standard templates and lists of input files.
 
-Provides an automated way to generate a full set of analysis files from an input
+Provides an automated way to generate a full set of analysis files from an inpu
 YAML template. Default templates are provided for common approaches which can be tweaked
 as needed.
 """
@@ -15,57 +15,68 @@ import os
 import shutil
 import urllib2
 
+import boto
 import yaml
 
 from bcbio import utils
 from bcbio.bam import fastq, sample_name
+from bcbio.upload import s3
 from bcbio.pipeline import run_info
 from bcbio.workflow.xprize import HelpArgParser
 
 def parse_args(inputs):
     parser = HelpArgParser(
         description="Create a bcbio_sample.yaml file from a standard template and inputs")
+    parser = setup_args(parser)
+    return parser.parse_args(inputs)
+
+def setup_args(parser):
     parser.add_argument("template", help=("Template name or path to template YAML file. "
                                           "Built in choices: freebayes-variant, gatk-variant, tumor-paired, "
                                           "noalign-variant, illumina-rnaseq, illumina-chipseq"))
     parser.add_argument("metadata", help="CSV file with project metadata. Name of file used as project name.")
     parser.add_argument("input_files", nargs="*", help="Input read files, in BAM or fastq format")
-    return parser.parse_args(inputs)
+    return parser
 
 # ## Prepare sequence data inputs
 
 def _prep_bam_input(f, i, base):
-    if not os.path.exists(f):
+    if not os.path.exists(f) and not f.startswith(utils.SUPPORTED_REMOTES):
         raise ValueError("Could not find input file: %s" % f)
     cur = copy.deepcopy(base)
-    cur["files"] = [os.path.abspath(f)]
-    cur["description"] = ((sample_name(f) if f.endswith(".bam") else None)
-                          or os.path.splitext(os.path.basename(f))[0])
+    if f.startswith(utils.SUPPORTED_REMOTES):
+        cur["files"] = [f]
+        cur["description"] = os.path.splitext(os.path.basename(f))[0]
+    else:
+        cur["files"] = [os.path.abspath(f)]
+        cur["description"] = ((sample_name(f) if f.endswith(".bam") else None)
+                              or os.path.splitext(os.path.basename(f))[0])
     return cur
 
 def _prep_fastq_input(fs, base):
     for f in fs:
-        if not os.path.exists(f):
+        if not os.path.exists(f) and not f.startswith(utils.SUPPORTED_REMOTES):
             raise ValueError("Could not find input file: %s" % f)
     cur = copy.deepcopy(base)
-    cur["files"] = [os.path.abspath(f) for f in fs]
+    cur["files"] = [os.path.abspath(f) if not f.startswith(utils.SUPPORTED_REMOTES) else f for f in fs]
     d = os.path.commonprefix([utils.splitext_plus(os.path.basename(f))[0] for f in fs])
     cur["description"] = fastq.rstrip_extra(d)
     return cur
 
+KNOWN_EXTS = {".bam": "bam", ".cram": "bam", ".fq": "fastq",
+              ".fastq": "fastq", ".txt": "fastq",
+              ".fastq.gz": "fastq", ".fq.gz": "fastq",
+              ".txt.gz": "fastq", ".gz": "fastq"}
+
 def _prep_items_from_base(base, in_files):
     """Prepare a set of configuration items for input files.
     """
     details = []
-    known_exts = {".bam": "bam", ".cram": "bam", ".fq": "fastq",
-                  ".fastq": "fastq", ".txt": "fastq",
-                  ".fastq.gz": "fastq", ".fq.gz": "fastq",
-                  ".txt.gz": "fastq", ".gz": "fastq"}
-    in_files = _expand_dirs(in_files, known_exts)
+    in_files = _expand_dirs(in_files, KNOWN_EXTS)
     in_files = _expand_wildcards(in_files)
 
     for i, (ext, files) in enumerate(itertools.groupby(
-            in_files, lambda x: known_exts.get(utils.splitext_plus(x)[-1].lower()))):
+            in_files, lambda x: KNOWN_EXTS.get(utils.splitext_plus(x)[-1].lower()))):
         if ext == "bam":
             for f in files:
                 details.append(_prep_bam_input(f, i, base))
@@ -108,7 +119,11 @@ def name_to_config(template):
     Handles well-known template names, pulled from GitHub repository and local
     files.
     """
-    if os.path.isfile(template):
+    if template.startswith(utils.SUPPORTED_REMOTES):
+        with utils.s3_handle(template) as in_handle:
+            config = yaml.load(in_handle)
+        txt_config = None
+    elif os.path.isfile(template):
         with open(template) as in_handle:
             txt_config = in_handle.read()
         with open(template) as in_handle:
@@ -184,23 +199,22 @@ def _set_global_vars(metadata):
                 metadata[sample][k] = global_var_sub[v]
     return metadata, global_vars
 
-def _parse_metadata(in_file):
+def _parse_metadata(in_handle):
     """Reads metadata from a simple CSV structured input file.
 
     samplename,batch,phenotype
     ERR256785,batch1,normal
     """
     metadata = {}
-    with open(in_file) as in_handle:
-        reader = csv.reader(in_handle)
-        while 1:
-            header = reader.next()
-            if not header[0].startswith("#"):
-                break
-        keys = [x.strip() for x in header[1:]]
-        for sinfo in (x for x in reader if not x[0].startswith("#")):
-            sample = sinfo[0].strip()
-            metadata[sample] = dict(zip(keys, (x.strip() for x in sinfo[1:])))
+    reader = csv.reader(in_handle)
+    while 1:
+        header = reader.next()
+        if not header[0].startswith("#"):
+            break
+    keys = [x.strip() for x in header[1:]]
+    for sinfo in (x for x in reader if not x[0].startswith("#")):
+        sample = sinfo[0].strip()
+        metadata[sample] = dict(zip(keys, (x.strip() for x in sinfo[1:])))
     metadata, global_vars = _set_global_vars(metadata)
     return metadata, global_vars
 
@@ -211,12 +225,17 @@ def _pname_and_metadata(in_file):
 
     For back compatibility, accepts the project name as an input, providing no metadata.
     """
-    if not os.path.isfile(in_file):
-        return _safe_name(in_file), {}, {}
+    if os.path.isfile(in_file):
+        with open(in_file) as in_handle:
+            md, global_vars = _parse_metadata(in_handle)
+        base = os.path.splitext(os.path.basename(in_file))[0]
+    elif in_file.startswith(utils.SUPPORTED_REMOTES):
+        with utils.s3_handle(in_file) as in_handle:
+            md, global_vars = _parse_metadata(in_handle)
+        base = os.path.splitext(os.path.basename(in_file))[0]
     else:
-        md, global_vars = _parse_metadata(in_file)
-        return (_safe_name(os.path.splitext(os.path.basename(in_file))[0]),
-                md, global_vars)
+        base, md, global_vars = _safe_name(in_file), {}, {}
+    return _safe_name(base), md, global_vars
 
 def _handle_special_yaml_cases(v):
     """Handle values that pass integer, boolean or list values.
@@ -233,7 +252,7 @@ def _handle_special_yaml_cases(v):
                     v = False
     return v
 
-def _add_metadata(item, metadata):
+def _add_metadata(item, metadata, remotes):
     """Add metadata information from CSV file to current item.
 
     Retrieves metadata based on 'description' parsed from input CSV file.
@@ -244,8 +263,11 @@ def _add_metadata(item, metadata):
       to key/value pairs there instead of metadata.
     """
     item_md = metadata.get(item["description"],
-                           metadata.get(os.path.basename(item["files"][0]), {}))
-    TOP_LEVEL = set(["description", "genome_build"])
+                           metadata.get(os.path.basename(item["files"][0]),
+                                        metadata.get(os.path.splitext(os.path.basename(item["files"][0]))[0], {})))
+    if remotes.get("region"):
+        item["algorithm"]["variant_regions"] = remotes["region"]
+    TOP_LEVEL = set(["description", "genome_build", "lane"])
     if len(item_md) > 0:
         if "metadata" not in item:
             item["metadata"] = {}
@@ -263,12 +285,36 @@ def _add_metadata(item, metadata):
                                                         os.path.basename(item["files"][0]))
     return item
 
+def _retrieve_remote(fnames):
+    """Retrieve remote inputs found in the same bucket as the template or metadata files.
+    """
+    for fname in fnames:
+        if fname.startswith(utils.SUPPORTED_REMOTES):
+            bucket_name, key_name = utils.s3_bucket_key(fname)
+            folder = os.path.dirname(key_name)
+            conn = boto.connect_s3()
+            bucket = conn.get_bucket(bucket_name)
+            inputs = []
+            regions = []
+            for key in bucket.get_all_keys(prefix=folder):
+                if key.name.endswith(tuple(KNOWN_EXTS.keys())):
+                    inputs.append("s3://%s/%s" % (bucket_name, key.name))
+                elif key.name.endswith((".bed", ".bed.gz")):
+                    regions.append("s3://%s/%s" % (bucket_name, key.name))
+            remote_base = "s3://{bucket_name}/{folder}".format(**locals())
+            return {"base": remote_base,
+                    "inputs": inputs,
+                    "region": regions[0] if len(regions) == 1 else None}
+    return {}
+
 def setup(args):
     template, template_txt = name_to_config(args.template)
     base_item = template["details"][0]
     project_name, metadata, global_vars = _pname_and_metadata(args.metadata)
-    items = [_add_metadata(item, metadata)
-             for item in _prep_items_from_base(base_item, args.input_files)]
+    remotes = _retrieve_remote([args.template, args.metadata])
+    inputs = args.input_files + remotes.get("inputs", [])
+    items = [_add_metadata(item, metadata, remotes)
+             for item in _prep_items_from_base(base_item, inputs)]
 
     out_dir = os.path.join(os.getcwd(), project_name)
     work_dir = utils.safe_makedir(os.path.join(out_dir, "work"))
@@ -284,3 +330,9 @@ def setup(args):
         print "Edit to finalize and run with:"
         print "  cd %s" % work_dir
         print "  bcbio_nextgen.py ../config/%s" % os.path.basename(out_config_file)
+        if remotes.get("base"):
+            remote_path = os.path.join(remotes["base"], os.path.basename(out_config_file))
+            bucket, key = utils.s3_bucket_key(remote_path)
+            s3.upload_file(out_config_file, bucket, key)
+            print "Also uploaded to AWS S3 in %s" % remotes["base"]
+            print "Run directly with bcbio_vm.py run %s" % remote_path
